@@ -91,13 +91,13 @@ Contains a single callback whose `condition` is a continuous function. The callb
     if the starting condition is less than the tolerance from zero, then no root will be detected.
     This is to stop repeat events happening immediately after a rootfinding event.
   - `repeat_nudge = 1//100`: This is used to set the next testing point after a
-    previously found zero. Defaults to 1//100, which means after a callback, the next
-    sign check will take place at t + dt*1//100 instead of at t to avoid repeats.
+    previously found zero. Defaults to `1//100`, which means after a callback, the next
+    sign check will take place at `t + dt*1//100` instead of at `t` to avoid repeats.
   - `initializealg = nothing`: In the context of a DAE, this is the algorithm that is used
     to run initialization after the effect. The default of `nothing` defers to the initialization
     algorithm provided in the `solve`.
 
-!!! warn
+!!! warning
 
     The effect of using a callback with a DAE needs to be done with care because the solution
     `u` needs to satisfy the algebraic constraints before taking the next step. For this reason,
@@ -318,11 +318,9 @@ DiscreteCallback(condition, affect!;
   - `condition`: This is a function `condition(u,t,integrator)` for declaring when
     the callback should be used. A callback is initiated if the condition evaluates
     to `true`. See the [Integrator Interface](@ref integrator) documentation for information about `integrator`.
-
-      + `affect!`: This is the function `affect!(integrator)` where one is allowed to
-        modify the current state of the integrator. For more information on what can
-        be done, see the [Integrator Interface](@ref integrator) manual page.
-
+  - `affect!`: This is the function `affect!(integrator)` where one is allowed to
+    modify the current state of the integrator. For more information on what can
+    be done, see the [Integrator Interface](@ref integrator) manual page.
   - `save_positions`: Boolean tuple for whether to save before and after the `affect!`.
     This saving will occur just before and after the event, only at event times, and
     does not depend on options like `saveat`, `save_everystep`, etc. (i.e. if
@@ -339,7 +337,7 @@ DiscreteCallback(condition, affect!;
     to run initialization after the effect. The default of `nothing` defers to the initialization
     algorithm provided in the `solve`.
 
-!!! warn
+!!! warning
 
     The effect of using a callback with a DAE needs to be done with care because the solution
     `u` needs to satisfy the algebraic constraints before taking the next step. For this reason,
